function y=americanputetl_sim(amount_invested,stock_price,strike,r,mu,...
    sigma,maturity,number_trials,number_steps,cl,hp)
% AMERICANPUTETL_SIM ETL of vanilla American put position estimated by a 
% binomial option valuation tree and Monte Carlo simulation
%
% Function estimates the ETL of a vanilla American put option position 
% using Monte Carlo simulation, with a binomial option valuation tree nested 
% within the MCS.
%
% The arguments are: the amount invested, the current stock price, the strike 
% price, the risk-free rate, the expected rate of return on the underlying asset,
% the stock volatility, the term to maturity, the number of iterations in the 
% Monte Carlo simulation exercise, the number of steps over the holding period
% at each of which early exercise is checked, the VaR confidence level and the 
% VaR holding period. 
%
% The returns and volatility are in annualised terms, and the maturity and holding]
% period are in days. The amount invested is positive (negative) if the option 
% position is long (short). The number of steps is at least 2.
% 
% The outputs are the MCS VaR estimate, and the bounds of the 95% confidence
% interval for our VaR, based on an order-statistics analysis of the 
% P/L distribution.
%
% NB: cl and hp are scalars.
%
% Revised by Kevin Dowd, November 12th, 2001.
% ****************************************************************************
tic % Start timer
%
% Precompute constants
%
annual_maturity=maturity/360; % Annualised maturity
annual_hp=hp/360; % Annualised holding period
N=number_steps; % Number of steps 
dt=annual_hp/N; % Size of time-increment equal to holding period
nudt=(mu-0.5*sigma^2)*dt;
sigmadt=sigma*sqrt(dt);
lnS=log(stock_price);
M=number_trials;
initial_option_price=americanputprice_binomial(stock_price,strike,r,sigma,maturity,N);
number_of_options=abs(amount_invested)/initial_option_price;
%
% Stock price simulation process
%
for i=1:M
    lnSt(i,1)=lnS+nudt+sigmadt*randn; 
    new_stock_price(i,1)=exp(lnSt(i,1)); % New stock price
    for j=2:N
        lnSt(i,j)=lnSt(i,j-1)+nudt+sigmadt*randn; 
        new_stock_price(i,j)=exp(lnSt(i,j)); % New stock price
    end
end
%
% Option calculation over time
% 
for i=1:M
   for j=1:N-1
      new_option_value(i,j)=...
          americanputprice_binomial(new_stock_price(i,j),strike,r,sigma,maturity-j*hp/N,N);
   end
end
%
% Profit/loss
%
Profit_or_loss=(new_option_value-initial_option_price)*number_of_options;
%
% Now adjust for short position 
%
if amount_invested<0 % If option position is short
    Profit_or_loss=-Profit_or_loss;    
end
%
%
% VaR estimation
%
y=hsetldfperc(Profit_or_loss, 0.5,cl); % VaR 
Confidence_interval=[hsetldfperc(Profit_or_loss, 0.025,cl), ...
        hsetldfperc(Profit_or_loss, 0.975,cl)]
%
toc % End timer
