function y=blackscholesputprice(varargin)
% BLACKSCHOLESPUTPRICE Price for generalised Black-Scholes put
%
% Function derives the price of a generalised European put option using the Black-Scholes 
% approach. 
%
% If there are five arguments, the first is the stock price, the second is the strike price, the 
% third is the risk-free rate, the fourth is volatility, and the fifth is the term to maturity. 
%
% This case corresponds to the standard BS option.
%
% If there are six arguments, the first is the stock price, the second is the strike price, the 
% third is the risk-free rate, the fourth is the own rate of return on the underlying asset (or 
% foreign risk-free rate or continuous dividend yield), the fifth is volatility, and the sixth is the 
% term to maturity. 
%
% This case corresponds to the standard European option with a continuous dividend yield
% or a standard European option on a foreign currency.
%
% Rates are expressed in annualised terms and maturity is in days.
%
% Revised by Kevin Dowd, July 16th, 2001.
% *****************************************************************************************
%
% Interpret arguments
%
if nargin<5,
    error('Too few arguments');
end
if nargin>6,
    error('Too many arguments');
end
if nargin ==5
    stock_price=varargin{1};
    strike=varargin{2};
    r=varargin{3};
    volatility=varargin{4};
    maturity=varargin{5};
    q=0;
end
if nargin ==6
    stock_price=varargin{1};
    strike=varargin{2};
    r=varargin{3};
    q=varargin{4};
    volatility=varargin{5};
    maturity=varargin{6};
end
% 
% Convert maturity from units of days to units of years
%
maturity=maturity/360;
%
% Distinguish cases of zero, negative and positive maturity
%
if maturity==0
    y=max(strike-stock_price,0); % Zero maturity option price
end
if maturity<0
    error('Maturity must be non-negative')
end
if maturity>0   
    %
    % d terms
    %
    d1=(log(stock_price/strike)+(r-q+(volatility^2)/2)*maturity)/(volatility*sqrt(maturity));
    d2=(log(stock_price/strike)+(r-q-(volatility^2)/2)*maturity)/(volatility*sqrt(maturity));
    %
    % Option price
    %
    y=-exp(-q*maturity)*normcdf(-d1)*stock_price+exp(-r*maturity)*strike*normcdf(-d2);
end