function y=boxcoxetl(loss_data,cl)
%
% BOXCOXETL ETL estimated with Box-Cox transformation
%
% Function estimates the ETL of a portfolio assuming loss data set 
% transformed using the Box-Cox transformation to make it as near 
% normal as possible, for specified confidence level and 
% holding period implied by data frequency.
% 
% The first argument is the daily loss data set, and the second 
% is the VaR confidence level. 
% 
% This basic Box-Cox approach assumes loss obverations are all positive.
%
% cl can be a scalar or a vector, and the output has the same dimension as cl.
%
% Reference: Scott A. Hamilton and Jeremy M. G. Taylor, "A comparison of the Box-Cox
% transformation method and nonparametric methods for estimating quantiles in 
% clinical data with repeated measures." J. Statist. Comput. Simul., Vol. 45, 1993, pp.
% 185-201.
% 
% Revised by Kevin Dowd, November 8th, 2001.
% *****************************************************************************************
% 
% Check that inputs have correct dimensions
%
[cl_row,cl_col]=size(cl);
if min(cl_row,cl_col)>1
    error('Confidence level must be a scalar or a vector');
end
% 
% To check that cl is read as a scalar or row vector as required
%
[cl_rows,cl_cols]=size(cl);
if cl_rows>cl_cols
    cl=cl';
end
%
% Check that inputs obey sign and value restrictions
%
if max(cl)>=1
    error('Confidence level(s) must be less than 1');
end
if min(cl)<=0
    error('Confidence level(s) must be greater than 0');
end
%
% ETL estimation
%
var=boxcoxvar(loss_data,cl); % HS VaR
   k=find(var<loss_data);% Finds indices of tail loss data 
   tail_losses=loss_data(k); % Creates data set of tail loss observations
   etl=mean(tail_losses);% ETL
   y=etl;


