function y=frechetetlfigure(mu,sigma,tail_index,cl,hp)
% FRECHETETLFIGURE Figure of Frechet ETL and pdf of losses
%
% Function gives figure showing the VaR and pdf of a portfolio assuming L/P is Frechet distributed,
% for specified confidence level and holding period.
% 
% Note that the long-right-hand tail is fitted to losses, not profits. 
%
% There are five arguments, the first is the assumed mean daily P/L, the 
% second is the assumed standard deviation of daily P/L, the third is the tail index, the 
% fourth is the VaR confidence level, and the fifth is the VaR holding period. 
%
% NB: Both cl and hp should be entered as scalars.
%
% Source: P. Embrechts, C. Kluppelberg and T. Mikosch, Modelling Extremal Events
% for Insurance and Finance. Berlin: Springer, 1997, p. 324.
%
% Revised by Kevin Dowd, November 11th, 2001.
% *****************************************************************************************
% 
% Check that inputs have correct dimensions
%
[mu_row,mu_col]=size(mu);
if max(mu_row,mu_col)>1
    error('Mu must be a scalar');
end
[sigma_row,sigma_col]=size(sigma);
if max(sigma_row,sigma_col)>1
    error('Standard deviation must be a scalar');
end
[tail_index_row,tail_index_col]=size(tail_index);
if max(tail_index_row,tail_index_col)>1
    error('Tail index must be a scalar');
end
[cl_row,cl_col]=size(cl);
if max(cl_row,cl_col)>1
    error('Confidence level must be a scalar');
end
[hp_row,hp_col]=size(hp);
if max(hp_row,hp_col)>1
    error('Holding period must be a scalar');
end
% 
% Check that parameters obey sign and value restrictions
%
if sigma<0
    error('Standard deviation must be non-negative');
end
if min(tail_index)<=0
    error('Tail index must be greater than 0');
end
if max(cl)>=1
    error('Confidence level must be less than 1');
end
if min(cl)<=0
    error('Confidence level must be greater than 0');
end
if min(hp)<=0
    error('Holding period must be greater than 0');
end
%
% Derivation of location and scale parameters
%
scale=sigma*sqrt(6)*sqrt(hp')/pi;
location=-mu*hp'-scale*.57722;
%
% VaR estimation
%
var=location*ones(size(cl))-(scale/tail_index)*(1-(-log(cl)).^-(tail_index));        
% Frechet VaR  
%
% Estimate ETL
%
n=1000;                          % Number of slices into which tail is divided 
cl0=cl;                             % Initial confidence level
w=var;                                                                                            
delta_cl=(1-cl)/n;               % Increment to confidence level as each slice is taken
for i=1:n-1
    cl=cl0+i*delta_cl;                         % Revised cl
    scale=sigma*sqrt(6)*sqrt(hp')/pi;
    location=-mu*hp'-scale*.57722;
    w=w+location*ones(size(cl))-(scale/tail_index)*(1-(-log(cl)).^-(tail_index));
end;
etl=w/n;                                               % ETL
%
% Plotting
%
x_min=mu+eps-sigma/tail_index; % Minimum value of x
x_max=location+6*sigma;
delta=(x_max-x_min)/100;
x=x_min:delta:x_max;
frechet_df=exp(-(1+tail_index*(x-location)/sigma).^(-tail_index^-1)); 
plot(x,frechet_df)
p=diff(frechet_df); 
x(:,end)=[];
plot(x,p);
r=[x_min,x_max,0,max(p)*1.1];
axis(r);
hold on;
%
% Insert line showing VaR
%
u=[var,var]; 
v=[0,.6*max(p)];
line=plot(u,v, 'Color','black');
%
% Insert line showing ETL
%
w=[etl,etl];
z=[0,.45*max(p)];
line=plot(w,z,'Color','black');
%
% Input data labels
%
cl_for_label=100*cl0;
text(mu,.95*max(p),'Input parameters','Fontweight','bold')
text(mu, .875*max(p),['Daily mean L/P = ',num2str(-mu)])
text(mu, .8*max(p),['St. dev. of daily L/P = ',num2str(sigma)])
text(mu, .725*max(p),['Tail index  = ',num2str(tail_index)])
text(mu, .65*max(p),['Holding period = ',num2str(hp),' day(s)'])
%
% VaR line label
%
text(var,.7*max(p),['VaR at ',num2str(cl_for_label),'% CL'],'Fontweight','bold','horizontal','left')
text(var,.65*max(p),['= ',num2str(var)],'Fontweight','bold','horizontal','left')
%
% ETL line label
%
text(etl,.55*max(p),['ETL ='],'Fontweight','bold','horizontal','left')
text(etl,.5*max(p),[num2str(etl)],'Fontweight','bold','horizontal','left')
%
% Labelling of axes
%
xlabel('Loss (+) / Profit (-)','horizontal','left','Fontweight','bold');
ylabel('Probability','rotation',90,'horizontal','center','Fontweight','bold');
title(['Frechet VaR and ETL'],'FontSize',12,'Fontweight','bold');
hold off;


