function y=frechetetlplot2D_cl(mu,sigma,tail_index,cl,hp)
% FRECHETETLPLOT2D_CL Plots Frechet ETL against confidence level 
%
% Function plots the ETL of a portfolio against confidence level, assuming losses are Frechet distributed,
% for range of confidence levels and a given holding period.
% 
% Note that the long-right-hand tail is fitted to losses, not profits. 
%
% There are five arguments, the first is the assumed mean daily P/L, the 
% second is the assumed standard deviation of daily P/L, the third is the tail index, the 
% fourth is the VaR confidence level, and the fifth is the VaR holding period. 
% 
% cl must be a vector, and cl must be a vector.
%
% Source: P. Embrechts, C. Kluppelberg and T. Mikosch, Modelling Extremal Events
% for Insurance and Finance. Berlin: Springer, 1997, p. 324.
%
% Revised by Kevin Dowd, November 11th, 2001.
% *****************************************************************************************
% 
% Check that inputs have correct dimensions
%
[mu_row,mu_col]=size(mu);
if max(mu_row,mu_col)>1
    error('Mu must be a scalar');
end
[sigma_row,sigma_col]=size(sigma);
if max(sigma_row,sigma_col)>1
    error('Standard deviation must be a scalar');
end
[tail_index_row,tail_index_col]=size(tail_index);
if max(tail_index_row,tail_index_col)>1
    error('Tail index must be a scalar');
end
[cl_row,cl_col]=size(cl);
if min(cl_row,cl_col)>1
    error('Confidence level must be a vector');
end
[hp_row,hp_col]=size(hp);
if max(hp_row,hp_col)>1
    error('Holding period must be a scalar');
end
% 
% To check that cl is read as a row vector as required
% 
[cl_rows,cl_cols]=size(cl);
if cl_rows>cl_cols
    cl=cl';
end
%
% Check that parameters obey sign and value restrictions
%
if sigma<0
    error('Standard deviation must be non-negative');
end
if min(tail_index)<=0
    error('Tail index must be greater than 0');
end
if max(cl)>=1
    error('Confidence level must be less than 1');
end
if min(cl)<=0
    error('Confidence level(s) must be greater than 0');
end
if min(hp)<=0
    error('Holding period must be greater than 0');
end
%
% Derivation of location and scale parameters
%
scale=sigma*sqrt(6)*sqrt(hp')/pi;
location=-mu*hp'-scale*.57722;
%
% VaR estimation
%
var=frechetvar(mu,sigma,tail_index,cl,hp);        
%
% ETL estimation
%
n=1000;                       % Number of slices into which tail is divided 
cl0=cl;                       % Initial confidence level
w=var;                                                
delta_cl=(1-cl)/n;           % Increment to confidence level as each slice is taken
for i=1:n-1
    cl=cl0+i*delta_cl;        % Revised cl
    scale=sigma*sqrt(6)*sqrt(hp')/pi;
    location=-mu*hp'-scale*.57722;
    w=w+location*ones(size(cl))-(scale/tail_index)*(1-(-log(cl)).^-(tail_index));   
    % NB Frechet term
end;
etl=w/n;
%
% Plotting
%
plot(cl0,etl);
axis;
cl_label=100*cl0;
%
% Input data labels
%
text(min(cl0)+.1*(max(cl0)-min(cl0)),max(etl)-.1*(max(etl)-min(etl)),'Input parameters','Fontweight','bold')
text(min(cl0)+.1*(max(cl0)-min(cl0)),max(etl)-.2*(max(etl)-min(etl)),['Daily mean L/P = ',num2str(-mu)])
text(min(cl0)+.1*(max(cl0)-min(cl0)),max(etl)-.3*(max(etl)-min(etl)),['St. dev. of daily L/P = ',num2str(sigma)])
text(min(cl0)+.1*(max(cl0)-min(cl0)),max(etl)-.4*(max(etl)-min(etl)),['Tail index = ',num2str(tail_index)])
text(min(cl0)+.1*(max(cl0)-min(cl0)),max(etl)-.5*(max(etl)-min(etl)),['Holding period = ',num2str(hp),' days'])
%
% Axis labels
%
xlabel('Confidence level','Fontweight','bold');
ylabel('ETL','rotation',0,'horizontal','right','Fontweight','bold');
title('Frechet ETL against confidence level','FontSize',12,'Fontweight','bold');


