function y=frechetvar(mu,sigma,tail_index,cl,hp)
% FRECHETVAR VaR for Frechet distributed P/L
%
% Function estimates the VaR of a portfolio assuming losses are Frechet distributed,
%  
% Note that the long-right-hand tail is fitted to losses, not profits. 
%
% There are five arguments, the first is the assumed mean daily P/L, the 
% second is the assumed standard deviation of daily P/L, the third is the tail index, the 
% fourth is the VaR confidence level, and the fifth is the VaR holding period. 
% 
% If cl and hp are both scalars, function gives a scalar answer.
% If cl is a vector, and hp is a scalar, function gives a row vector of VaRs.
% If cl is a scalar and hp is a vector, function  gives a column vector of VaRs.
% If cl and hp are both vectors, function gives a matrix of VaRs with cl read across rows
% and hp down columns.
%
% Source: P. Embrechts, C. Kluppelberg and T. Mikosch, Modelling Extremal
% Events for Insurance and Finance. Berlin: Springer, 1997, p. 324.
%
% Revised by Kevin Dowd, November 11th, 2001.
% ***********************************************************************
% 
% Check that inputs have correct dimensions
%
[mu_row,mu_col]=size(mu);
if max(mu_row,mu_col)>1
    error('Mu must be a scalar');
end
[sigma_row,sigma_col]=size(sigma);
if max(sigma_row,sigma_col)>1
    error('Standard deviation must be a scalar');
end
[tail_index_row,tail_index_col]=size(tail_index);
if max(tail_index_row,tail_index_col)>1
    error('Tail index must be a scalar');
end
[cl_row,cl_col]=size(cl);
if min(cl_row,cl_col)>1
    error('Confidence level must be a scalar or a vector');
end
[hp_row,hp_col]=size(hp);
if min(hp_row,hp_col)>1
    error('Holding period must be a scalar or a vector');
end
% 
% To check that cl is read as a scalar or row vector as required
% And to check that hp is read as a scalar or column vector as required
%
[cl_rows,cl_cols]=size(cl);
if cl_rows>cl_cols
    cl=cl';
end
[hp_rows,hp_cols]=size(hp);
if hp_rows>hp_cols
    hp=hp';
end
%
% Check that parameters obey sign and value restrictions
%
if sigma<0
    error('Standard deviation must be non-negative');
end
if min(tail_index)<=0
    error('Tail index must be greater than 0');
end
if max(cl)>=1
    error('Confidence level(s) must be less than 1');
end
if min(cl)<=0
    error('Confidence level(s) must be greater than 0');
end
if min(hp)<=0
    error('Holding period(s) must be greater than 0');
end
%
% Derivation of location and scale parameters
%
scale=sigma*sqrt(6)*sqrt(hp')/pi;
location=-mu*hp'-scale*.57722;
%
% VaR estimation
%
y=location*ones(size(cl))-(scale/tail_index)*(1-(-log(cl)).^-(tail_index));        
% Frechet VaR
