function y=gumbeletlplot2D_cl(varargin)
%GUMBELETLPLOT2D_CL Plots normal ETL against confidence level 
%
% Function plots the ETL of a portfolio against confidence level, assuming  is L/P is Gumbel distributed,
% for specified confidence level and holding period.
% 
% Note that the long-right-hand tail is fitted to losses, not profits. 
%
% If there are three arguments, the first argument is a vector of daily P/L data, the second
% is the VaR confidence level, and the third is the VaR holding period in days. 
% 
% If there are four arguments, the first is the assumed mean daily P/L, the 
% second is the assumed standard deviation of daily P/L, the third is the VaR confidence 
% level, and the fourth is the VaR holding period. 
% 
% cl must be a row vector, and hp must be a scalar.
%
% Revised by Kevin Dowd, November 11th, 2001.
% *****************************************************************************************
% 
% Determine if there are three or four arguments, and ensure that arguments
% are read as intended
%
if nargin<3,
    error('Too few arguments');
end
if nargin>4,
    error('Too many arguments');
end
if nargin ==4
    mu=varargin{1};
    sigma=varargin{2};
    cl=varargin{3};
    hp=varargin{4};
end
if nargin==3
    mu=mean(varargin{1});
    sigma=std(varargin{1});
    cl=varargin{2};
    hp=varargin{3};
end
% 
% Check that inputs have correct dimensions
%
[mu_row,mu_col]=size(mu);
if max(mu_row,mu_col)>1
    error('Mean must be a scalar');
end
[sigma_row,sigma_col]=size(sigma);
if max(sigma_row,sigma_col)>1
    error('Standard deviation must be a scalar');
end
[cl_row,cl_col]=size(cl);
if min(cl_row,cl_col)>1
    error('Confidence level must be a vector');
end
[hp_row,hp_col]=size(hp);
if max(hp_row,hp_col)>1
    error('Holding period must be a scalar');
end
% 
% To check that cl is read as a row vector  as required
%
[cl_rows,cl_cols]=size(cl);
if cl_rows>cl_cols
    cl=cl';
end
%
% Check that inputs obey sign and value restrictions
%
if sigma<0
    error('Standard deviation must be non-negative');
end
if max(cl)>=1
    error('Confidence levels must be less than 1');
end
if min(cl)<=0
    error('Confidence levels must be greater than 0');
end
if min(hp)<=0
    error('Holding period must be greater than 0');
end
%
% Derivation of location and scale parameters
%
scale=sigma*sqrt(6)*sqrt(hp')/pi;
location=-mu*hp'-scale*.57722;
%
% VaR estimation
%
var=location*ones(size(cl))-scale*log(log(cl.^-1));     % Gumbel VaR  
%
% ETL estimation
%
n=1000;                                           % Number of slices into which tail is divided 
cl0=cl;                                              % Initial confidence level
v=var;                                                
delta_cl=(1-cl)/n;                           % Increment to confidence level as each slice is taken
for i=1:n-1
cl=cl0+i*delta_cl;                           % Revised cl
scale=sigma*sqrt(6)*sqrt(hp')/pi;
location=-mu*hp'-scale*.57722;
v=v+location*ones(size(cl))-scale*log(log(cl.^-1)); 
end;
v=v/n;                                                  % ETL
%
% Plotting
%
plot(cl0,v);
axis;
%
% Input data labels
%
text(min(cl0)+.1*(max(cl0)-min(cl0)),max(v)-.1*(max(v)-min(v)),'Input parameters','Fontweight','bold');
text(min(cl0)+.1*(max(cl0)-min(cl0)),max(v)-.2*(max(v)-min(v)),['Daily mean L/P = ',num2str(-mu)]);
text(min(cl0)+.1*(max(cl0)-min(cl0)),max(v)-.3*(max(v)-min(v)),['St. dev. of daily L/P = ',num2str(sigma)]);
text(min(cl0)+.1*(max(cl0)-min(cl0)),max(v)-.4*(max(v)-min(v)),['Holding period = ',num2str(hp),' day(s)']);
%
% Axis labels
%
xlabel('Confidence level','Fontweight','bold');
ylabel('ETL','rotation',0,'horizontal','right','Fontweight','bold');
title(['Gumbel ETL against confidence level'],'FontSize',12,'Fontweight','bold');


