function y=lognormaletlfigure(varargin)
% LOGNORMALETLFIGURE  Figure of lognormal VaR and ETL and pdf against L/P
% 
% Function gives figure showing the VaR and pdf against L/P of a portfolio 
% assuming geometric returns are normally distributed, for specified 
% confidence level and holding period.
% 
% If there are four arguments, the first argument is a vector of daily
% geometric return data, the second is the size of the investment, the 
% third is the VaR confidence level, and the fourth is the VaR holding
% period in days. 
% 
% If there are five arguments, the first is the assumed daily mean geometric 
% return, the second is the assumed standard deviation of daily geometric 
% returns, the third is the size of the investment, the fourth is the 
% VaR confidence level, and the fifth is the VaR holding period. 
% 
% Note: Both cl and hp should be entered as scalars.
%
% Revised by Kevin Dowd, June 2, 2001.
%*****************************************************************************************
% 
% Determine if there are four or five arguments, and ensure that 
% arguments are read as intended
%
if nargin<4,
    error('Too few arguments');
end
if nargin>5,
    error('Too many arguments');
end
if nargin==5
    mu=varargin{1};
    sigma=varargin{2};
    investment=varargin{3};
    cl=varargin{4};
    hp=varargin{5};
end
if nargin==4
    mu=mean(varargin{1});
    sigma=std(varargin{1});
    investment=varargin{2};
    cl=varargin{3};
    hp=varargin{4};
end
% 
% Check that inputs have correct dimensions
%
[mu_row,mu_col]=size(mu);
if max(mu_row,mu_col)>1
    error('Mean must be a scalar');
end
[sigma_row,sigma_col]=size(sigma);
if max(sigma_row,sigma_col)>1
    error('Standard deviation must be a scalar');
end
[cl_row,cl_col]=size(cl);
if min(cl_row,cl_col)>1
    error('Confidence level must be a scalar or a vector');
end
[hp_row,hp_col]=size(hp);
if min(hp_row,hp_col)>1
    error('Holding period must be a scalar or a vector');
end
% 
% To check that cl is read as a scalar or row vector  as required
% And to check that hp is read as a scalar or column vector as required
%
[cl_rows,cl_cols]=size(cl);
if cl_rows>cl_cols
    cl=cl';
end
[hp_rows,hp_cols]=size(hp);
if hp_rows>hp_cols
    hp=hp';
end
%
% Check that inputs obey sign and value restrictions
%
if sigma<0
    error('Standard deviation must be non-negative');
end
if max(cl)>=1
    error('Confidence level(s) must be less than 1');
end
if min(cl)<=0
    error('Confidence level(s) must be greater than 0');
end
if min(hp)<=0
    error('Holding period(s) must be greater than 0');
end
%
% Message to indicate how matrix of results is to be interpreted,
% if cl and hp both vary and results are given in matrix form
% 
if max(cl_row,cl_col)>1&max(hp_row,hp_col)>1
    disp('VaR results with confidence level varying across row and holding period down column')
end
%
% VaR estimation
%
var=investment-exp(sigma*sqrt(hp')*norminv(1-cl,0,1)+mu*hp'*ones(size(cl))...
    +log(investment)); %VaR 
%
% ETL estimation
%
n=1000;                          % Number of slices into which tail is divided 
cl0=cl;                          % Initial confidence level
term=var;                                                                                             
delta_cl=(1-cl)/n;      % Increment to confidence level as each slice is taken
for i=1:n-1
cl=cl0+i*delta_cl;                           % Revised cl
term=term+investment-exp(sigma*sqrt(hp')*norminv(1-cl,0,1)+mu*hp'*ones(size(cl))...
    +log(investment));
end;
etl=term/n;                                           % ETL
%
% Set up figure
%
x_min=mu-5*sigma;
x_max=investment;
delta=(x_max-x_min)/100;
x=x_min:delta:x_max;
p=lognpdf(investment-x,mu,sigma); 
plot(x,p); 
r=[x_min,x_max,0,max(p)*1.1];
axis(r);
hold on;
%
% Insert line showing VaR
%
u=[var,var]; 
v=[0,.6*max(p)];
line=plot(u,v, 'Color','black');
%
% Insert line showing ETL
%
w=[etl,etl];
z=[0,.45*max(p)];
line=plot(w,z,'Color','black');
%
% Input data labels
%
cl_for_label=100*cl0;
text(mu-4.5*sigma,.95*max(p),'Input parameters','Fontweight','bold')
text(mu-4.5*sigma, .875*max(p),['Daily mean geometric return = ',num2str(mu)])
text(mu-4.5*sigma, .8*max(p),['St. dev. of daily geometric returns = ',num2str(sigma)])
text(mu-4.5*sigma, .725*max(p),['Investment size = ',num2str(investment)])
text(mu-4.5*sigma, .65*max(p),['Holding period = ',num2str(hp),' day(s)'])
%
% VaR line label
%
text(var,.7*max(p),['VaR at ',num2str(cl_for_label),'% CL'],'Fontweight','bold','horizontal','left')
text(var,.65*max(p),['= ',num2str(var)],'Fontweight','bold','horizontal','left')
%
% ETL line label
%
text(etl,.55*max(p),['ETL ='],'Fontweight','bold','horizontal','left')
text(etl,.5*max(p),[num2str(etl)],'Fontweight','bold','horizontal','left')
%
% Labelling of axes
%
xlabel('Loss (+) / Profit (-)','horizontal','left','Fontweight','bold');
ylabel('Probability','rotation',90,'horizontal','center','Fontweight','bold');
title(['Lognormal VaR and ETL'],'FontSize',12,'Fontweight','bold');
hold off;