function y=lognormaletlplot2D_hp(varargin)
% LOGNORMALETLPLOT2D_HP Plots lognormal ETL against holding period 
%
% Function plots the ETL of a portfolio against holding period, assuming
% geometric returns are normally distributed, for specified confidence 
% level and specified range of holding periods.
% 
% If there are four arguments, the first argument is a vector of daily
% geometric return data, the second is the size of the investment, the 
% third is the VaR confidence level , and the fourth is the VaR holding
% period vector in days. 
% 
% If there are five arguments, the first is the assumed daily mean geometric 
% return, the second is the assumed standard deviation of daily geometric 
% returns, the third is the size of the investment, the fourth is the 
% VaR confidence level, and the fifth is the VaR holding period. 
% 
% cl must be a scalar, and hp must be a vector.
%
% Revised by Kevin Dowd, June 1, 2001.
% *****************************************************************************************
% 
% Determine if there are four or five arguments, and ensure that 
% arguments are read as intended
%
if nargin<4,
    error('Too few arguments');
end
if nargin>5,
    error('Too many arguments');
end
if nargin==5
    mu=varargin{1};
    sigma=varargin{2};
    investment=varargin{3};
    cl=varargin{4};
    hp=varargin{5};
end
if nargin==4
    mu=mean(varargin{1});
    sigma=std(varargin{1});
    investment=varargin{2};
    cl=varargin{3};
    hp=varargin{4};
end
% 
% Check that inputs have correct dimensions
%
[mu_row,mu_col]=size(mu);
if max(mu_row,mu_col)>1
    error('Mean must be a scalar');
end
[sigma_row,sigma_col]=size(sigma);
if max(sigma_row,sigma_col)>1
    error('Standard deviation must be a scalar');
end
[hp_row,hp_col]=size(hp);
if min(hp_row,hp_col)>1
    error('Holding period must be a vector');
end
[cl_row,cl_col]=size(cl);
if max(cl_row,cl_col)>1
    error('Confidence level must be a scalar');
end
% 
% To check that hp is read as a row vector  as required
%
[hp_rows,hp_cols]=size(hp);
if hp_rows>hp_cols
    hp=hp';
end
%
% Check that inputs obey sign and value restrictions
%
if sigma<0
    error('Standard deviation must be non-negative');
end
if max(cl)>=1
    error('Confidence levels must be less than 1');
end
if min(cl)<=0
    error('Confidence levels must be greater than 0');
end
if min(hp)<=0
    error('Holding period must be greater than 0');
end
%
% VaR estimation
%
var=investment-exp(sigma*sqrt(hp')*norminv(1-cl,0,1)+mu*hp'*ones(size(cl))...
    +log(investment)); % VaR 
%
% ETL estimation
%
n=1000;                      % Number of slices into which tail is divided 
cl0=cl;                      % Initial confidence level
w=var;                                                
delta_cl=(1-cl)/n;           % Increment to confidence level as each slice is taken
for i=1:n-1
cl=cl0+i*delta_cl;           % Revised cl
w=w+investment-exp(sigma*sqrt(hp')*norminv(1-cl,0,1)+mu*hp'*ones(size(cl))...
    +log(investment));
end;
etl=w/n;
plot(hp,etl);
axis;
cl_label=100*cl0;
%
% Input data labels
%
text(min(hp)+.1*(max(hp)-min(hp)),max(etl)-.1*(max(etl)-min(etl)),'Input parameters','Fontweight','bold')
text(min(hp)+.1*(max(hp)-min(hp)),max(etl)-.2*(max(etl)-min(etl)),['Daily mean geometric return = ',num2str(-mu)])
text(min(hp)+.1*(max(hp)-min(hp)),max(etl)-.3*(max(etl)-min(etl)),['St. dev. of daily geometric returns = ',num2str(sigma)])
text(min(hp)+.1*(max(hp)-min(hp)),max(etl)-.4*(max(etl)-min(etl)),['Investment size = ',num2str(investment)])
text(min(hp)+.1*(max(hp)-min(hp)),max(etl)-.5*(max(etl)-min(etl)),['Confidence level = ',num2str(cl_label),'%'])
%
% Axis labels
%
xlabel('Holding period','Fontweight','bold');
ylabel('ETL','rotation',0,'horizontal','right','Fontweight','bold');
title('Lognormal ETL against holding period','FontSize',12,'Fontweight','bold');
