function y=tvarplot3D(varargin)
% TVARPLOT3D Plots t VaR in 3D against confidence level and holding period
%  
% Function estimates the VaR of a portfolio assuming P/L is t distributed,
% for specified ranges of confidence level and holding period.
% 
% If there are four arguments, the first argument is a vector of daily P/L data, the second
% is the number of degrees of freedom, the third is the VaR confidence level, and the 
% last is the VaR holding period in days. 
% 
% If there are five arguments, the first is the assumed mean daily P/L, the 
% second is the assumed standard deviation of daily P/L, the third is the number of degrees
% of freedom, the fourth is the VaR confidence level, and the fifth is the VaR holding period. 
%
% Revised by Kevin Dowd, November 4th, 2001.
% *****************************************************************************************
% 
% Determine if there are three or four arguments, and ensure that arguments
% are read as intended
%
if nargin<4,
    error('Too few arguments');
end
if nargin>5,
    error('Too many arguments');
end
if nargin ==5
    mu=varargin{1};
    sigma=varargin{2};
    df=varargin{3};
    cl=varargin{4};
    hp=varargin{5};
end
if nargin==4
    mu=mean(varargin{1});
    sigma=std(varargin{1});
    df=varargin{2};
    cl=varargin{3};
    hp=varargin{4};
end
% 
% Check that inputs have correct dimensions
%
[mu_row,mu_col]=size(mu);
if max(mu_row,mu_col)>1
    error('Mean must be a scalar');
end
[sigma_row,sigma_col]=size(sigma);
if max(sigma_row,sigma_col)>1
    error('Standard deviation must be a scalar');
end
[df_row,df_col]=size(df);
if max(df_row,df_col)>1
    error('Number of degrees of freedom must be a scalar');
end
[cl_row,cl_col]=size(cl);
if max(cl_row,cl_col)==1
    error('Confidence level must be a vector');
end
[hp_row,hp_col]=size(hp);
if max(hp_row,hp_col)==1
    error('Holding period must be a vector');
end
% 
% To check that cl is read as a row vector  as required
% And to check that hp is read as a column vector as required
%
[cl_rows,cl_cols]=size(cl);
if cl_rows>cl_cols
    cl=cl';
end
[hp_rows,hp_cols]=size(hp);
if hp_rows>hp_cols
    hp=hp';
end
%
% Check that inputs obey sign and value restrictions
%
if sigma<0
    error('Standard deviation must be non-negative');
end
if df<3
    error('Number of degrees of freedom must be at least 3 for first two moments of distribution to be defined');
end
if max(cl)>=1
    error('Confidence levels must be less than 1');
end
if min(cl)<=0
    error('Confidence levels must be greater than 0');
end
if min(hp)<=0
    error('Holding periods must be greater than 0');
end
%
% VaR estimation
%
var=-sigma*sqrt(hp')*sqrt((df-2)/df)*tinv((1-cl),df)-mu*hp'*ones(size(cl)); %t-VaR 
%
% Plotting
%
surf(cl,hp,var);
axis;
xlabel('Confidence level','Fontweight','bold','vertical','bottom');
ylabel('Holding period','Fontweight','bold','vertical','bottom');
zlabel('VaR','rotation',0,'horizontal','right','Fontweight','bold');
title(['t VaR (with df =',num2str(df),') against confidence level and holding period'],'FontSize',12,'Fontweight','bold');
shading interp;

