function upandoutcallvar_sim(amount_invested,stock_price,strike,barrier,r,mu,sigma,...
    maturity,number_trials,cl,hp)
% UPANDOUTCALLVAR_SIM VaR of up-and-out barrier call estimated by Monte Carlo simulation
%
% Function estimates the VaR of a up-and-out barrier call option position 
% using Monte Carlo simulation.
%
% The arguments are: the amount invested, the current stock price, the strike 
% price, the barrier, the risk-free rate, the expected rate of return on the underlying
% asset,the stock volatility, the term to maturity, the number of iterations in the 
% Monte Carlo simulation exercise, the VaR confidence level and the VaR holding period. 
%
% The returns and volatility are in annualised terms, and the maturity and holding
% period are in days. The amount invested is positive (negative) if the option 
% position is long (short).
%
% The outputs are the MCS VaR estimate, and the bounds of the 95% confidence
% interval for our VaR, based on an order-statistics analysis of the 
% P/L distribution.
%
% NB: cl and hp are scalars.
%
% Revised by Kevin Dowd, August 25th, 2001.
% ****************************************************************************
tic % Start timer
%
% Precompute constants
%
% annual_maturity=maturity/360; % Annualised maturity
annual_hp=hp/360; % Annualised holding period
N=100; % Number of incremental steps in path, taken as 100
dt=annual_hp/N; % Annualised size of time-increment 
nudt=(mu-0.5*sigma^2)*dt;
sigmadt=sigma*sqrt(dt);
lnS=log(stock_price);
M=number_trials;
initial_option_price=upandoutcallprice(stock_price,strike,barrier,r,0,sigma,maturity)
number_of_options=abs(amount_invested)/initial_option_price;
%
% Stock price simulation process
%
for i=1:M
    lnSt(i,1)=lnS+nudt+sigmadt*randn; 
    new_stock_price(i,1)=exp(lnSt(i,1)); % New stock price
    for j=2:N
        lnSt(i,j)=lnSt(i,j-1)+nudt+sigmadt*randn; 
        new_stock_price(i,j)=exp(lnSt(i,j)); % New stock price
    end
end
%
% P/L calculation for long position
% 
for i=1:M
    for j=1:N
    % If stock price hits or exceeds barrier, option becomes worthless
        if new_stock_price(i,j)>=barrier
            option_value(i,j)=0;
            option_value(i,j+1)=option_value(i,j);
        else % Alternatively, option is valued as up and out barrier call
            option_value(i,j)=upandoutcallprice(new_stock_price(i,j),strike,...
                barrier,r,0,sigma,maturity-j*hp/N);
        end
    end
    Profit_or_loss(i)=(option_value(i,N)-initial_option_price)*number_of_options;
end
%
% Now adjust for short position 
%
if amount_invested<0 % If option position is short
    Profit_or_loss=-Profit_or_loss;    
end
%
% VaR estimation
%
VaR=hsvar(Profit_or_loss,cl) % VaR
Confidence_interval=[hsvardfperc(Profit_or_loss, 0.025,cl), ...
        hsvardfperc(Profit_or_loss, 0.975,cl)]
%
toc % End timer