function h = normalqqplot(data)
%NORMALQQPLOT Displays a normal quantile-quantile plot.
%   
%   Function makes an empirical QQ-plot of the quantiles of
%   the data set 'data' versus the quantiles of a normal distribution.
%
%   The purpose of the quantile-quantile plot is to determine whether
%   the sample in 'data' is drawn from a normal (i.e., Gaussian) distribution.
% 
%   The only argument is the data set.
%
%   Copyright 1993-2001 The MathWorks, Inc. and Kevin Dowd. 
%   $Revised Kevin Dowd, March 25, 2001. $
% **************************************************************
   x=data;
   mu=mean(x);
   sigma=std(x);
   y  =  sort(x);
   [x,n]  = plotpos(y);
   x  = norminv(x,mu,sigma);          % This is theoretical normal quantile
   xx = x;
   yy = y;

   if (((size(x,1)==n) | (size(x,1)==1 & size(x,2)==n)) & ~any(isnan(x)))
      xx = sort(x);
   else
      xx = prctile(x,pvec);
   end
   if (((size(y,1)==n) | (size(y,1)==1 & size(y,2)==n)) & ~any(isnan(y)))
      yy = sort(y);
   else
      yy=prctile(y,pvec);
   end

q1x = prctile(x,25);
q3x = prctile(x,75);
q1y = prctile(y,25);
q3y = prctile(y,75);
qx = [q1x; q3x];
qy = [q1y; q3y];


dx = q3x - q1x;
dy = q3y - q1y;
slope = dy./dx;
centerx = (q1x + q3x)/2;
centery = (q1y + q3y)/2;
maxx = max(x);
minx = min(x);
maxy = centery + slope.*(maxx - centerx);
miny = centery - slope.*(centerx - minx);

mx = [minx; maxx];
my = [miny; maxy];


hh = plot(xx,yy,'+',qx,qy,'-',mx,my,'-.');
if nargout == 1
  h = hh;
end

   xlabel('Normal Quantiles', 'Fontweight','bold')
   ylabel('Quantiles of Input Sample','Fontweight','bold')
   title ('QQ Plot of Sample Data versus Normal','FontSize', 12,'Fontweight','bold')

%===================== helper function ====================
function [pp,n] = plotpos(sx)
%PLOTPOS Compute plotting positions for a probability plot
%   PP = PLOTPOS(SX) compute the plotting positions for a probabilty
%   plot of the columns of SX (or for SX itself if it is a vector).
%   SX must be sorted before being passed into PLOTPOS.  The ith
%   value of SX has plotting position (i-0.5)/n, where n is
%   the number of rows of SX.  NaN values are removed before
%   computing the plotting positions.
%
%   [PP,N] = PLOTPOS(SX) also returns N, the largest sample size
%   among the columns of SX.  This N can be used to set axis limits.

[n, m] = size(sx);
if n == 1
   sx = sx';
   n = m;
   m = 1;
end

nvec = sum(~isnan(sx));
pp = repmat((1:n)', 1, m);
pp = (pp-.5) ./ repmat(nvec, n, 1);
pp(isnan(sx)) = NaN;

if (nargout > 1)
   n = max(nvec);  % sample size for setting axis limits
end


