function y=frechetvarplot2D_cl(mu,sigma,tail_index,n, cl,hp)
% Function plots the VaR of a portfolio against confidence level, assuming extreme losses 
% are Frechet distributed, for specified range of confidence level and a 
% given holding period.
%
% Note that the long-right-hand tail is fitted to losses, not profits. 
% 
% There are six arguments, the first is the assumed location parameter for daily L/P, the 
% second is the assumed scale parameter of daily L/P, the third is the tail index, the 
% fourth is the block size from which the maxima are drawn, the fifth is the VaR confidence 
% level, and the fifth is the VaR holding period. 
% 
% cl must be a vector, and hp must be a scalar.
%
% Source: P. Embrechts, C. Kluppelberg and T. Mikosch, Modelling Extremal
% Events for Insurance and Finance. Berlin: Springer, 1997, p. 324, and R.-D. Reiss and 
% M. Thomas Statistical Analysis of Extreme Values from Insurance, Finance,
% Hydrology and Other Fields, Basel: Birkhaueser, 1997, pp. 15, 18.
%
% Revised by Kevin Dowd, February 28, 2005.
%*****************************************************************************************
% 
% Check that inputs have correct dimensions
%
[mu_row,mu_col]=size(mu);
if max(mu_row,mu_col)>1
    error('Mu must be a scalar');
end
[sigma_row,sigma_col]=size(sigma);
if max(sigma_row,sigma_col)>1
    error('Standard deviation must be a scalar');
end
[tail_index_row,tail_index_col]=size(tail_index);
if max(tail_index_row,tail_index_col)>1
    error('Tail index must be a scalar');
end
[cl_row,cl_col]=size(cl);
if min(cl_row,cl_col)>1
    error('Confidence level must be a vector');
end
[hp_row,hp_col]=size(hp);
if max(hp_row,hp_col)>1
    error('Holding period must be a scalar');
end
% 
% To check that cl is read as a row vector as required
% 
[cl_rows,cl_cols]=size(cl);
if cl_rows>cl_cols
    cl=cl';
end
%
% Check that parameters obey sign and value restrictions
%
if sigma<0
    error('Standard deviation must be non-negative');
end
if min(tail_index)<=0
    error('Tail index must be greater than 0');
end
if max(cl)>=1
    error('Confidence level(s) must be less than 1');
end
if min(cl)<=0
    error('Confidence level(s) must be greater than 0');
end
if min(hp)<=0
    error('Holding period(s) must be greater than 0');
end
%
% Derivation of location and scale parameters
%
zeta=tail_index;
%
% VaR estimation
%
var=frechetvar(mu,sigma,tail_index,n,cl,hp)
% 
% Plotting
%
plot(cl,var);
axis;
%
% Input data labels
%
text(min(cl)+.1*(max(cl)-min(cl)),max(var)-.1*(max(var)-min(var)),'Input parameters','Fontweight','bold')
text(min(cl)+.1*(max(cl)-min(cl)),max(var)-.2*(max(var)-min(var)),['Location parameter for daily L/P = ',num2str(mu)])
text(min(cl)+.1*(max(cl)-min(cl)),max(var)-.3*(max(var)-min(var)),['Scale parameter for daily L/P = ',num2str(sigma)])
text(min(cl)+.1*(max(cl)-min(cl)),max(var)-.4*(max(var)-min(var)),['Tail index = ',num2str(tail_index)])
text(min(cl)+.1*(max(cl)-min(cl)),max(var)-.5*(max(var)-min(var)),['Holding period = ',num2str(hp),' day(s)'])
%
% Axis labels
%
xlabel('Confidence level','Fontweight','bold');
ylabel('VaR','rotation',0,'horizontal','right','Fontweight','bold');
title(['Frechet VaR against confidence level'],'FontSize',12,'Fontweight','bold')


