function y=gumbelvarplot2D_cl(mu,sigma,n, cl,hp)
% Function plots the VaR of a portfolio against confidence level, assuming extreme losses are Gumbel distributed,
% for specified confidence level and holding period.
%
% Note that the long-right-hand tail is fitted to losses, not profits. 
% 
% Arguments: the first is the assumed location parameter for daily L/P, the 
% second is the assumed scale paramater for daily L/P, the third is the assumed block 
% size from which the maxima are drawn, the fourth is the VaR confidence 
% level, and the fifth is the VaR holding period. 
% 
% cl must be a row vector, and hp must be a scalar.
%
% Revised by Kevin Dowd, Feb 28, 2005.
% *****************************************************************************************
% 
% Check that inputs have correct dimensions
%
[mu_row,mu_col]=size(mu);
if max(mu_row,mu_col)>1
    error('Mean must be a scalar');
end
[sigma_row,sigma_col]=size(sigma);
if max(sigma_row,sigma_col)>1
    error('Standard deviation must be a scalar');
end
[cl_row,cl_col]=size(cl);
if min(cl_row,cl_col)>1
    error('Confidence level must be a vector');
end
[hp_row,hp_col]=size(hp);
if max(hp_row,hp_col)>1
    error('Holding period must be a scalar');
end
% 
% To check that cl is read as a row vector  as required
%
[cl_rows,cl_cols]=size(cl);
if cl_rows>cl_cols
    cl=cl';
end
%
% Check that inputs obey sign and value restrictions
%
if sigma<0
    error('Standard deviation must be non-negative');
end
if max(cl)>=1
    error('Confidence levels must be less than 1');
end
if min(cl)<=0
    error('Confidence levels must be greater than 0');
end
if min(hp)<=0
    error('Holding period must be greater than 0');
end
%
% VaR estimation
%
var=mu*ones(size(cl))-sigma*log(-n*log(cl));   % Gumbel VaR   
% 
% Plotting
%
plot(cl,var);
axis;
%
% Input data labels
%
text(min(cl)+.1*(max(cl)-min(cl)),max(var)-.1*(max(var)-min(var)),'Input parameters','Fontweight','bold')
text(min(cl)+.1*(max(cl)-min(cl)),max(var)-.2*(max(var)-min(var)),['Location parameter for daily L/P = ',num2str(mu)])
text(min(cl)+.1*(max(cl)-min(cl)),max(var)-.3*(max(var)-min(var)),['Scale parameter for daily L/P = ',num2str(sigma)])
text(min(cl)+.1*(max(cl)-min(cl)),max(var)-.4*(max(var)-min(var)),['Holding period = ',num2str(hp),' day(s)'])
%
% Axis labels
%
xlabel('Confidence level','Fontweight','bold');
ylabel('VaR','rotation',0,'horizontal','right','Fontweight','bold');
title(['Gumbel VaR against confidence level'],'FontSize',12,'Fontweight','bold')

