function y=logtesplot2D_hp(varargin)
% LOGTESPLOT2D_hp Plots logt ES against holding period 
%
% Function plots the ES of a portfolio against holding period, assuming
% geometric returns are Student t distributed, for specified range of 
% confidence level and a given holding period.
% 
% If there are five arguments, the first argument is a vector of daily
% geometric return data, the second is the size of the investment, the 
% third is number of degrees of freedom in the t distribution, the 
% fourth is the VaR confidence level, and the fifth is the VaR holding
% period in days. 
% 
% If there are six arguments, the first is the assumed daily mean geometric 
% return, the second is the assumed standard deviation of daily geometric 
% returns, the third is the size of the investment, the fourth is the 
% number of degrees of freedom in the t distribution, the fifth is
% the VaR confidence level, and the sixth is the VaR holding period. 
% 
% cl must be a vector, and hp must be a scalar.
%
% Revised by Kevin Dowd, November 7th, 2001.
% *****************************************************************************************
% 
% Determine if there are five or six arguments, and ensure that 
% arguments are read as intended
%
if nargin<5,
    error('Too few arguments');
end
if nargin>6,
    error('Too many arguments');
end
if nargin==6
    mu=varargin{1};
    sigma=varargin{2};
    investment=varargin{3};
    df=varargin{4};
    cl=varargin{5};
    hp=varargin{6};
end
if nargin==5
    mu=mean(varargin{1});
    sigma=std(varargin{1});
    investment=varargin{2};
    df=varargin{3};
    cl=varargin{4};
    hp=varargin{5};
end
% 
% Check that inputs have correct dimensions
%
[mu_row,mu_col]=size(mu);
if max(mu_row,mu_col)>1
    error('Mean must be a scalar');
end
[sigma_row,sigma_col]=size(sigma);
if max(sigma_row,sigma_col)>1
    error('Standard deviation must be a scalar');
end
[hp_row,hp_col]=size(hp);
if min(hp_row,hp_col)>1
    error('Holding period must be a vector');
end
[cl_row,cl_col]=size(cl);
if max(cl_row,cl_col)>1
    error('Confidence level must be a scalar');
end
% 
% To check that cl is read as a row vector as required
%
[hp_rows,hp_cols]=size(hp);
if hp_cols>hp_rows
    hp=hp';
end
%
% Check that inputs obey sign and value restrictions
%
if sigma<0
    error('Standard deviation must be non-negative');
end
if max(cl)>=1
    error('Confidence levels must be less than 1');
end
if min(cl)<=0
    error('Confidence levels must be greater than 0');
end
if min(hp)<=0
    error('Holding period must be greater than 0');
end
%
% VaR estimation
%
var=investment-exp(((df-2)/df)*sigma*sqrt(hp')*tinv(1-cl,df)+mu*hp'*ones(size(cl))...
    +log(investment)); % VaR 
% 
% ES estimation
%
n=1000;                            % Number of slices into which tail is divided 
cl0=cl;                            % Initial confidence level
v=var;                                                
delta_cl=(1-cl)/n;                 % Increment to confidence level as each slice is taken
for i=1:n-1
cl=cl0+i*delta_cl;                 % Revised cl
v=v+investment-exp(((df-2)/df)*sigma*sqrt(hp')*tinv(1-cl,df)+mu*hp'*ones(size(cl))...
    +log(investment));
end;
v=v/n;                                                  % ES
% 
% Plotting
%
plot(hp,v);
axis;
%
% Input data labels
%
text(min(hp)+.1*(max(hp)-min(hp)),max(v)-.1*(max(v)-min(v)),'Input parameters','Fontweight','bold')
text(min(hp)+.1*(max(hp)-min(hp)),max(v)-.2*(max(v)-min(v)),['Daily mean geometric return = ',num2str(mu)])
text(min(hp)+.1*(max(hp)-min(hp)),max(v)-.3*(max(v)-min(v)),['St. dev. of geometric returns = ',num2str(sigma)])
text(min(hp)+.1*(max(hp)-min(hp)),max(v)-.4*(max(v)-min(v)),['Degrees of freedom = ',num2str(df)])
text(min(hp)+.1*(max(hp)-min(hp)),max(v)-.5*(max(v)-min(v)),['Investment size = ',num2str(investment)])
text(min(hp)+.1*(max(hp)-min(hp)),max(v)-.6*(max(v)-min(v)),['Confidence level = ',num2str(cl0),'%'])
%
% Axis labels
%
xlabel('Holding period','Fontweight','bold');
ylabel('ES','rotation',0,'horizontal','right','Fontweight','bold');
title(['Logt ES against holding period'],'FontSize',12,'Fontweight','bold')

