function y=logtesplot3D(varargin)
% LOGTESPLOT3D Plots logt ES in 3D against confidence level
% and holding period
%   
% If there are five arguments, the first argument is a vector of daily
% geometric return data, the second is the size of the investment, the 
% third is number of degrees of freedom in the t distribution, the 
% fourth is the VaR confidence level, and the fifth is the VaR holding
% period in days. 
% 
% If there are six arguments, the first is the assumed daily mean geometric 
% return, the second is the assumed standard deviation of daily geometric 
% returns, the third is the size of the investment, the fourth is the 
% number of degrees of freedom in the t distribution, the fifth is
% the VaR confidence level, and the sixth is the VaR holding period. 
%
% Revised by Kevin Dowd, November 7th, 2001.
% *****************************************************************************************
% 
% Determine if there are five or six arguments, and ensure that 
% arguments are read as intended
%
if nargin<5,
    error('Too few arguments');
end
if nargin>6,
    error('Too many arguments');
end
if nargin==6
    mu=varargin{1};
    sigma=varargin{2};
    investment=varargin{3};
    df=varargin{4};
    cl=varargin{5};
    hp=varargin{6};
end
if nargin==5
    mu=mean(varargin{1});
    sigma=std(varargin{1});
    investment=varargin{2};
    df=varargin{3};
    cl=varargin{4};
    hp=varargin{5};
end
% 
% Check that inputs have correct dimensions
%
[mu_row,mu_col]=size(mu);
if max(mu_row,mu_col)>1
    error('Mean must be a scalar');
end
[sigma_row,sigma_col]=size(sigma);
if max(sigma_row,sigma_col)>1
    error('Standard deviation must be a scalar');
end
[cl_row,cl_col]=size(cl);
if max(cl_row,cl_col)==1
    error('Confidence level must be a vector');
end
[hp_row,hp_col]=size(hp);
if max(hp_row,hp_col)==1
    error('Holding period must be a vector');
end
% 
% To check that cl is read as a row vector  as required
% And to check that hp is read as a column vector as required
%
[cl_rows,cl_cols]=size(cl);
if cl_rows>cl_cols
    cl=cl';
end
[hp_rows,hp_cols]=size(hp);
if hp_rows>hp_cols
    hp=hp';
end
%
% Check that inputs obey sign and value restrictions
%
if sigma<0
    error('Standard deviation must be non-negative');
end
if max(cl)>=1
    error('Confidence levels must be less than 1');
end
if min(cl)<=0
    error('Confidence levels must be greater than 0');
end
if min(hp)<=0
    error('Holding periods must be greater than 0');
end
%
% VaR estimation
%
var=investment-exp(((df-2)/df)*sigma*sqrt(hp')*tinv(1-cl,df)+mu*hp'*ones(size(cl))...
    +log(investment)); %VaR 
%
% ES estimation
%
n=1000;                              % Number of slices into which tail is divided 
cl0=cl;                             % Initial confidence level
v=var;                                                
delta_cl=(1-cl)/n;        % Increment to confidence level as each slice is taken
for i=1:n-1
cl=cl0+i*delta_cl;                         % Revised cl
v=v+investment-exp(((df-2)/df)*sigma*sqrt(hp')*tinv(1-cl,df)+mu*hp'*ones(size(cl))...
    +log(investment));
end;
v=v/n;
% 
% Plotting
%
surf(cl0,hp,v);
axis;
xlabel('Confidence level','Fontweight','bold','vertical','bottom');
ylabel('Holding period','Fontweight','bold','vertical','bottom');
zlabel('ES','rotation',0,'horizontal','right','Fontweight','bold');
title('Logt ES against confidence level and holding period','FontSize',12,'Fontweight','bold');
shading interp;
