function y=boxcoxvar(PandL_data,cl)
%
% BOXCOXVAR VaR estimated with Box-Cox transformation
%
% Function estimates the VaR of a portfolio assuming Pand L data set transformed using the Box-Cox
% transformation to make it as near normal as possible, for specified confidence level and 
% holding period implied by data frequency.
% 
% The first argument is the daily Pand L data set, and the second is the VaR confidence 
% level. 
%
% cl can be a scalar or a vector, and the output has the same dimension as cl.
%
% Reference: Scott A. Hamilton and Jeremy M. G. Taylor, "A comparison of the Box-Cox
% transformation method and nonparametric methods for estimating quantiles in 
% clinical data with repeated measures." J. Statist. Comput. Simul., Vol. 45, 1993, pp.
% 185-201.
% 
% Revised by Kevin Dowd, November 8th, 2001.
% *****************************************************************************************
% 
% Check that inputs have correct dimensions
%
[cl_row,cl_col]=size(cl);
if min(cl_row,cl_col)>1
    error('Confidence level must be a scalar or a vector');
end
% 
% To check that cl is read as a scalar or row vector as required
%
[cl_rows,cl_cols]=size(cl);
if cl_rows>cl_cols
    cl=cl';
end
%
% Check that inputs obey sign and value restrictions
%
if max(cl)>=1
    error('Confidence level(s) must be less than 1');
end
if min(cl)<=0
    error('Confidence level(s) must be greater than 0');
end
%
% Transform data and obtain lambda
%
loss_data=-PandL_data;
loss_data=loss_data-min(loss_data)+1;
loss_data=sort(loss_data);
[transdat, lambda]=boxcox(loss_data);
%
% Estimate mean and standard deviation of transformed data
%
mu=mean(transdat); % 
sigma=std(transdat); % 
%
% VaR estimation
%
for i=1:length(cl);
    VaR(i)=(1+lambda*(mu+sigma*norminv(cl(i),0,1)))^(1/lambda)+min(-PandL_data)-1; % i-thVaR 
end
y=VaR; 

