function y=normalesplot3D(varargin)
% NORMALESPLOT3D Plots normal ES in 3D against confidence level and holding period
%  
% Function plots the VaR of a portfolio assuming P/L is normally distributed,
% for specified ranges of confidence level and holding period.
% 
% If there are three arguments, the first argument is a vector of daily P/L data, the second
% is the VaR confidence level, and the third is the VaR holding period in days. 
% 
% If there are four arguments, the first is the assumed mean daily P/L, the 
% second is the assumed standard deviation of daily P/L, the third is the VaR confidence 
% level, and the fourth is the VaR holding period. 
%
% Revised by Kevin Dowd, February 22, 2005.
% *****************************************************************************************
% 
% Determine if there are three or four arguments, and ensure that arguments
% are read as intended
%
if nargin<3,
    error('Too few arguments');
end
if nargin>4,
    error('Too many arguments');
end
if nargin ==4
    mu=varargin{1};
    sigma=varargin{2};
    cl=varargin{3};
    hp=varargin{4};
end
if nargin==3
    mu=mean(varargin{1});
    sigma=std(varargin{1});
    cl=varargin{2};
    hp=varargin{3};
end
% 
% Check that inputs have correct dimensions
%
[mu_row,mu_col]=size(mu);
if max(mu_row,mu_col)>1
    error('Mean must be a scalar');
end
[sigma_row,sigma_col]=size(sigma);
if max(sigma_row,sigma_col)>1
    error('Standard deviation must be a scalar');
end
[cl_row,cl_col]=size(cl);
if max(cl_row,cl_col)==1
    error('Confidence level must be a vector');
end
[hp_row,hp_col]=size(hp);
if max(hp_row,hp_col)==1
    error('Holding period must be a vector');
end
% 
% To check that cl is read as a row vector  as required
% And to check that hp is read as a column vector as required
%
[cl_rows,cl_cols]=size(cl);
if cl_rows>cl_cols
    cl=cl';
end
[hp_rows,hp_cols]=size(hp);
if hp_rows>hp_cols
    hp=hp';
end
%
% Check that inputs obey sign and value restrictions
%
if sigma<0
    error('Standard deviation must be non-negative');
end
if max(cl)>=1
    error('Confidence levels must be less than 1');
end
if min(cl)<=0
    error('Confidence levels must be greater than 0');
end
if min(hp)<=0
    error('Holding periods must be greater than 0');
end
%
% VaR estimation
%
var=-sigma*sqrt(hp')*norminv(1-cl,0,1)-mu*hp'*ones(size(cl)); %VaR 
%
% ES estimation
%
es=normales(mu,sigma,cl,hp);
% 
% Plotting
%
surf(cl,hp,es);
axis;
xlabel('Confidence level','Fontsize',10,'Fontweight','bold','vertical','bottom');
ylabel('Holding period','Fontsize',10,'Fontweight','bold','vertical','bottom');
zlabel('ES','rotation',0,'Fontsize',10,'horizontal','right','Fontweight','bold');
title('Normal ES against confidence level and holding period','FontSize',12,'Fontweight','bold');
shading interp;


