function y=normalvaresplot2D_cl(varargin)
% NORMALESPLOT2D_CL Plots normal VaR and es against confidence level 
%
% Function plots the VaR and ES of a portfolio against confidence level, assuming P/L is normally distributed,
% for specified confidence level and holding period.
% 
% If there are three arguments, the first argument is a vector of daily P/L data, the second
% is the VaR confidence level, and the third is the VaR holding period in days. 
% 
% If there are four arguments, the first is the assumed mean daily P/L, the 
% second is the assumed standard deviation of daily P/L, the third is the VaR confidence 
% level, and the fourth is the VaR holding period. 
% 
% cl must be a vector, and hp must be a scalar.
%
% Revised by Kevin Dowd, November 4th, 2001. 
% *****************************************************************************************
% 
% Determine if there are three or four arguments, and ensure that arguments
% are read as intended
%
if nargin<3,
    error('Too few arguments');
end
if nargin>4,
    error('Too many arguments');
end
if nargin ==4
    mu=varargin{1};
    sigma=varargin{2};
    cl=varargin{3};
    hp=varargin{4};
end
if nargin==3
    mu=mean(varargin{1});
    sigma=std(varargin{1});
    cl=varargin{2};
    hp=varargin{3};
end
% 
% Check that inputs have correct dimensions
%
[mu_row,mu_col]=size(mu);
if max(mu_row,mu_col)>1
    error('Mean must be a scalar');
end
[sigma_row,sigma_col]=size(sigma);
if max(sigma_row,sigma_col)>1
    error('Standard deviation must be a scalar');
end
[cl_row,cl_col]=size(cl);
if min(cl_row,cl_col)>1
    error('Confidence level must be a vector');
end
[hp_row,hp_col]=size(hp);
if max(hp_row,hp_col)>1
    error('Holding period must be a scalar');
end
% 
% To check that cl is read as a row vector  as required
%
[cl_rows,cl_cols]=size(cl);
if cl_rows>cl_cols
    cl=cl';
end
%
% Check that inputs obey sign and value restrictions
%
if sigma<0
    error('Standard deviation must be non-negative');
end
if max(cl)>=1
    error('Confidence levels must be less than 1');
end
if min(cl)<=0
    error('Confidence levels must be greater than 0');
end
if min(hp)<=0
    error('Holding period must be greater than 0');
end
%
% VaR estimation
%
var=-sigma*sqrt(hp')*norminv(1-cl,0,1)-mu*hp'*ones(size(cl)); %VaR 
% 
% ES estimation
%
es=normales(mu,sigma,cl,hp);
% 
% Plotting
%
plot(cl,es,cl,var);
axis;
%
% Input data labels
%
text(min(cl)+.1*(max(cl)-min(cl)),max(es)-.1*(max(es)-min(es)),'Input parameters','Fontweight','bold');
text(min(cl)+.1*(max(cl)-min(cl)),max(es)-.2*(max(es)-min(es)),['Daily mean L/P = ',num2str(-mu)]);
text(min(cl)+.1*(max(cl)-min(cl)),max(es)-.3*(max(es)-min(es)),['St. dev. of daily L/P = ',num2str(sigma)]);
text(min(cl)+.1*(max(cl)-min(cl)),max(es)-.4*(max(es)-min(es)),['Holding period = ',num2str(hp),' day(s)']);
%
% VaR and ES labels
%
text(max(cl)-.4*(max(cl)-min(cl)),min(var)+.3*(max(var)-min(var)),'Upper line - ES');
text(max(cl)-.4*(max(cl)-min(cl)),min(var)+.2*(max(var)-min(var)),'Lower line - VaR');
%
% Axis labels
%
xlabel('Confidence level','Fontweight','bold');
ylabel('VaR/ES','rotation',90,'horizontal','center','Fontweight','bold');
title(['Normal VaR and ES against confidence level'],'FontSize',12,'Fontweight','bold');


