function y=tesfigure(varargin)
% TESFIGURE Figure of t VaR and ES and pdf of L/P
% 
% Function gives figure showing the VaR and ES and pdf of a portfolio assuming P/L is t distributed,
% for specified confidence level and holding period.
% 
% If there are four arguments, the first argument is a vector of daily P/L data, the second
% is the number of degrees of freedom, the third is the VaR confidence level, and the 
% last is the VaR holding period in days. 
% 
% If there are five arguments, the first is the assumed mean daily P/L, the 
% second is the assumed standard deviation of daily P/L, the third is the number of degrees
% of freedom, the fourth is the VaR confidence level, and the fifth is the VaR holding period. 
% 
% Note: Both cl and hp should be entered as scalars.
%
% Source: M. Evans, N. Hastings, and B. Peacock "Statistical Distributions", 3rd edition, New York:
% John Wiley, chapters 38 and 39.
%
% Revised by Kevin Dowd, November 4th, 2001.
% *****************************************************************************************
% 
% Determine if there are four or five arguments, and ensure that arguments
% are read as intended
%
if nargin<4,
    error('Too few arguments');
end
if nargin>5,
    error('Too many arguments');
end
if nargin ==5
    mu=varargin{1};
    sigma=varargin{2};
    df=varargin{3};
    cl=varargin{4};
    hp=varargin{5};
end
if nargin==4
    mu=mean(varargin{1});
    sigma=std(varargin{1});
    df=varargin{2};
    cl=varargin{3};
    hp=varargin{4};
end
% 
% Check that inputs have correct dimensions
%
[mu_row,mu_col]=size(mu);
if max(mu_row,mu_col)>1
    error('Mean must be a scalar');
end
[sigma_row,sigma_col]=size(sigma);
if max(sigma_row,sigma_col)>1
    error('Standard deviation must be a scalar');
end
[df_row,df_col]=size(sigma);
if max(df_row,df_col)>1
    error('Number of degrees of freedom must be a scalar');
end
[cl_row,cl_col]=size(cl);
if max(cl_row,cl_col)>1
    error('Confidence level must be a scalar');
end
[hp_row,hp_col]=size(hp);
if max(hp_row,hp_col)>1
    error('Holding period must be a scalar');
end
% 
% Check that inputs obey sign and value restrictions
%
if sigma<0
    error('Standard deviation must be non-negative');
end
if df<3
    error('Number of degrees of freedom must be at least 3 for first two moments of distribution to be defined.');
end
if max(cl)>=1
    error('Confidence level(s) must be less than 1');
end
if min(cl)<=0
    error('Confidence level(s) must be greater than 0');
end
if min(hp)<=0
    error('Holding period(s) must be greater than 0');
end
%
% VaR estimation
%
var=-sigma*sqrt(hp')*sqrt((df-2)/df)*tinv((1-cl),df)-mu*hp'*ones(size(cl)); %t-VaR 
%
% Estimate ES
%
n=1000;                                           % Number of slices into which tail is divided 
cl0=cl;                                              % Initial confidence level
w=var;                                                                                             
delta_cl=(1-cl)/n;                            % Increment to confidence level as each slice is taken
for i=1:n-1
cl=cl0+i*delta_cl;                         % Revised cl
w=w-sigma*sqrt(hp')*sqrt((df-2)/df)*tinv((1-cl),df)-mu*hp'*ones(size(cl));
end;
es=w/n;                                               % ES
%
% Set up figure
%
x_min=-mu-5*sigma;
x_max=-mu+5*sigma;
delta=(x_max-x_min)/100;
x=x_min:delta:x_max;
p=tpdf((x-mu)/sigma,df);;
plot(x,p); 
r=[x_min,x_max,0,max(p)*1.1];
axis(r);
hold on;
%
% Insert line showing VaR
%
u=[var,var]; 
v=[0,.6*max(p)];
line=plot(u,v, 'Color','black');
%
% Insert line showing ES
%
w=[es,es];
z=[0,.45*max(p)];
line=plot(w,z,'Color','black');
%
% Input data labels
%
cl_for_label=100*cl0;
text(-mu-4.5*sigma,.95*max(p),'Input parameters','Fontweight','bold')
text(-mu-4.5*sigma, .875*max(p),['Daily mean L/P = ',num2str(-mu)])
text(-mu-4.5*sigma, .8*max(p),['St. dev. of daily L/P = ',num2str(sigma)])
text(-mu-4.5*sigma, .725*max(p),['Degrees of freedom = ',num2str(df)])
text(-mu-4.5*sigma, .65*max(p),['Holding period = ',num2str(hp),' day(s)'])
%
% VaR line label
%
text(var,.7*max(p),['VaR at ',num2str(cl_for_label),'% CL'],'Fontweight','bold','horizontal','left')
text(var,.65*max(p),['= ',num2str(var)],'Fontweight','bold','horizontal','left')
%
% ES line label
%
text(es,.55*max(p),['ES ='],'Fontweight','bold','horizontal','left')
text(es,.5*max(p),[num2str(es)],'Fontweight','bold','horizontal','left')
%
% Labelling of axes
%
xlabel('Loss (+) / Profit (-)','horizontal','left','Fontweight','bold');
ylabel('Probability','rotation',90,'horizontal','center','Fontweight','bold');
title(['t VaR and ES'],'FontSize',12,'Fontweight','bold');
hold off;